AsyncPolicy

Struct AsyncPolicy 

pub struct AsyncPolicy<B: Backend, P: Policy<B>> { /* private fields */ }
An asynchronous policy using an inference server with autobatching.

Implementations

Source

impl<B, P> AsyncPolicy<B, P>

pub fn new(autobatch_size: usize, inner_policy: P) -> Self

Create the policy.

Arguments
  • autobatch_size - Number of observations to accumulate before running a pass of inference.
  • inner_policy - The policy used to take actions.
pub fn increment_agents(&self, num: usize)

Increment the number of agents using the inference server.

pub fn decrement_agents(&self, num: usize)

Decrement the number of agents using the inference server.