pub struct AsyncPolicy<B: Backend, P: Policy<B>> { /* private fields */ }Expand description
An asynchronous policy using an inference server with autobatching.
Implementations
Sourceimpl<B, P> AsyncPolicy<B, P>
impl<B, P> AsyncPolicy<B, P>
Sourcepub fn new(autobatch_size: usize, inner_policy: P) -> Self
pub fn new(autobatch_size: usize, inner_policy: P) -> Self
Create the policy.
Arguments
autobatch_size- Number of observations to accumulate before running a pass of inference.inner_policy- The policy used to take actions.
Sourcepub fn increment_agents(&self, num: usize)
pub fn increment_agents(&self, num: usize)
Increment the number of agents using the inference server.
Sourcepub fn decrement_agents(&self, num: usize)
pub fn decrement_agents(&self, num: usize)
Decrement the number of agents using the inference server.